@@ -12,12 +12,9 @@ from pythonjsonlogger import jsonlogger
 logger = logging.getLogger()
 
 
-log_format = lambda x: ['%({0:s})s'.format(i) for i in x]
-custom_format = ' '.join(log_format(["filename", "levelname", "msecs", "message", "msg"]))
-
 logger.setLevel(level=logging.DEBUG)
 logHandler = logging.StreamHandler()
-formatter = jsonlogger.JsonFormatter(custom_format)
+formatter = jsonlogger.JsonFormatter('%(levelname)s %(asctime)s %(filename)s %(funcName)s %(message)s')
 logHandler.setFormatter(formatter)
 logger.addHandler(logHandler)
 
